# Mollie integration for Drupal Commerce

* Provides payment method for Drupal Commerce (not Drupal Payment)
* @see https://www.drupal.org/project/commerce
* @see https://github.com/mollie/mollie-api-php

# Payment methods that are integrated

* Default: Commerce Checkout
* Minimal: Commerce Order + GET-endpoint

# Uses Mollie webhook to verify payments a-synchronously

* @see https://www.mollie.com/en/docs/webhook

# Installation

* ```$ composer require drupal/commerce_mollie```
* ```$ composer update drupal/commerce_mollie --with-dependencies```
* Enable 'commerce mollie' in your Drupal installation
* Config payment-gateway @ /admin/commerce/config/payment-gateways
* As order-workflow choose 'Default, with validation' @ /admin/commerce/config/order-types/default/edit

# Usage

## /commerce_mollie/payment_redirect/{commerce_order}

```
// Example function how to generate URL with CSRF token.
function getOrderPaymentUrlForOrder(Order $order) {

  // Generate URL from route.
  $orderPaymentUrl = Url::fromRoute('commerce_mollie.payment_redirect', [
    'commerce_order' => $order->id(),
  ]);
  // Generate csrf-token for route with it's parameters.
  $_csrf_token = \Drupal::csrfToken()->get($orderPaymentUrl->getInternalPath());

  // Generate redirect_back_url.
  $redirect_back_url = Url::fromUri('internal:/redirect-back-here')
    ->setAbsolute()
    ->toString();

  // Add _csrf_token and redirect_back_url as query parameters.
  $orderPaymentUrl->setOptions([
    'absolute' => TRUE,
    'query' => [
      'token' => $_csrf_token,
      'redirect_back_url' => $redirect_back_url,
    ],
  ]);
  return $orderPaymentUrl->toString();
}

```
