<?php

namespace Drupal\commerce_mollie\Controller;

use Drupal\commerce_order\entity\Order;
use Drupal\commerce_payment\Entity\Payment;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Routing\TrustedRedirectResponse;

/**
 * Starts payment without the checkout form pane.
 *
 * Can be used without commerce/checkout and commerce/cart.
 *
 * @package Drupal\commerce_mollie\Controller
 */
class MolliePaymentUrl extends ControllerBase {

  /**
   * Redirect to Mollie.
   *
   * \Drupal\commerce_payment\Entity\PaymentInterface $payment.
   *
   * @param Order $commerce_order
   *   The order to be payed.
   *
   * @return TrustedRedirectResponse
   *   Redirects user to Mollie.
   */
  public function doOrderPayment(Order $commerce_order) {
    $order = $commerce_order;

    // Get the default payment-gateway.
    $entityManager = \Drupal::service('entity.manager');
    $gateways = $entityManager->getStorage('commerce_payment_gateway')
      ->getQuery()
      ->execute();
    /* @todo resolve this in a smart way */
    /* @todo validate this is a mollie gateway */
    /* @see https://www.drupal.org/node/2827144 */
    $default_payment_gateway = reset($gateways);

    // Create Payment object.
    $values = [
      'payment_gateway' => $default_payment_gateway,
      'payment_method' => 'mollie',
      'order_id' => $order->id(),
      'amount' => $order->getTotalPrice(),
      'state' => 'draft',
    ];
    $payment = Payment::create($values);

    /** @var \Drupal\commerce_mollie\Plugin\Commerce\PaymentGateway\Mollie $payment_gateway_plugin */
    $payment_gateway_plugin = $payment->getPaymentGateway()->getPlugin();

    // Setup redirect_back_url.
    $params = \Drupal::request()->query->all();
    if (isset($params['redirect_back_url'])) {
      $redirect_back_url = $params['redirect_back_url'];
    }
    else {
      global $base_url;
      $redirect_back_url = $base_url;
    }
    $payment_gateway_plugin->setRedirectUrl($redirect_back_url);

    // Create Payment on Mollie's side.
    $payment_gateway_plugin->createRemotePayment($payment);
    $mollie_payment_url = $payment_gateway_plugin->getMolliePaymentUrl();

    // Apply payment 'authorize' transition.
    $capture_transition = $payment->getState()
      ->getWorkflow()
      ->getTransition('authorize');
    $payment->getState()->applyTransition($capture_transition);
    $payment->save();

    return new TrustedRedirectResponse($mollie_payment_url);
  }

}
